@@ -5,16 +5,10 @@ YAZAR_POSTA = 'keyiflerolsun@gmail.com'
 
 PAKET       = 'TRSehirler'
 
-VERSIYON    = '0.1.1'
+VERSIYON    = '0.1.2'
 
 REPO        = 'https://github.com/keyiflerolsun/TRSehirler'
 ACIKLAMA    = 'Türkiye Cumhuriyeti Devleti Şehirlerini; İl, Plaka, Telefon veya İlçe bilgisinden bulun..'
-ANAHTAR_KLM = ['TRSehirler', 'KekikAkademi', 'keyiflerolsun']
+ANAHTAR_KLM = [PAKET, 'KekikAkademi', 'keyiflerolsun']
 
-GEREKSINIM  = [
-    "tinydb==4.2.0",
-    "tabulate==0.8.7",
-    "attrdict==2.0.1"
-]
-
-from TRSehirler.Sehirler import Sehir
\ No newline at end of file
+from TRSehirler.Sehirler import Sehir
